@@ -112,7 +112,7 @@ class AppTaskData(AbstractModel):
         :param TaskErrMsg: 错误信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type TaskErrMsg: str
-        :param Source: 任务来源,0:默认值(私域), 1:灵犀, 2:灵鲲
+        :param Source: 任务来源,0:小程序诊断, 1:预留字段(暂未使用), 2:app诊断(android)
         :type Source: int
         :param AppInfo: 应用信息
         :type AppInfo: :class:`tencentcloud.acp.v20220105.models.AppInfoItem`
@@ -163,7 +163,7 @@ class CreateAppScanTaskRepeatRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Source: 任务来源, 0:默认值(私域), 1:灵犀, 2:灵鲲;
+        :param Source: 任务来源, 0:小程序诊断, 1:预留字段(暂未使用), 2:app诊断(android), 3:app漏洞扫描;
         :type Source: int
         :param Platform: 应用平台, 0:android, 1:ios, 2:小程序
         :type Platform: int
@@ -173,16 +173,20 @@ class CreateAppScanTaskRepeatRequest(AbstractModel):
         :type OrgTaskID: str
         :param AppPackage: App包名
         :type AppPackage: str
-        :param FileID: 上传的文件ID(灵犀诊断必填)
+        :param FileID: 上传的文件ID(任务来源为1时必填)
         :type FileID: str
-        :param AppDownloadUrl: 软件下载链接地址(灵鲲诊断必填)
+        :param AppDownloadUrl: 软件下载链接地址(任务来源为2时必填)
         :type AppDownloadUrl: str
-        :param PrivacyTextUrl: 隐私文本下载地址(灵鲲诊断必填)
+        :param PrivacyTextUrl: 隐私文本下载地址(任务来源为2时必填)
         :type PrivacyTextUrl: str
         :param AppName: 应用名称
         :type AppName: str
         :param PrivacyTextName: 隐私申明文件名称
         :type PrivacyTextName: str
+        :param AppSha1: 软件Sha1值(PrivacyTextMD5不为空时必填)
+        :type AppSha1: str
+        :param PrivacyTextMD5: 隐私申明文本md5(AppSha1不为空时必填)
+        :type PrivacyTextMD5: str
         """
         self.Source = None
         self.Platform = None
@@ -194,6 +198,8 @@ class CreateAppScanTaskRepeatRequest(AbstractModel):
         self.PrivacyTextUrl = None
         self.AppName = None
         self.PrivacyTextName = None
+        self.AppSha1 = None
+        self.PrivacyTextMD5 = None
 
 
     def _deserialize(self, params):
@@ -207,6 +213,8 @@ class CreateAppScanTaskRepeatRequest(AbstractModel):
         self.PrivacyTextUrl = params.get("PrivacyTextUrl")
         self.AppName = params.get("AppName")
         self.PrivacyTextName = params.get("PrivacyTextName")
+        self.AppSha1 = params.get("AppSha1")
+        self.PrivacyTextMD5 = params.get("PrivacyTextMD5")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -250,21 +258,21 @@ class CreateAppScanTaskRequest(AbstractModel):
         r"""
         :param TaskType: 任务类型, 0:基础版, 1:专家版, 2:本地化
         :type TaskType: int
-        :param Source: 任务来源, 0:默认值(私域), 1:灵犀, 2:灵鲲;
+        :param Source: 任务来源, 0:小程序诊断, 1:预留字段(暂未使用), 2:app诊断(android), 3:app漏洞扫描;
         :type Source: int
         :param Platform: 应用平台, 0:android, 1:ios, 2:小程序
         :type Platform: int
         :param AppPackage: App包名
         :type AppPackage: str
-        :param AppName: App名称
+        :param AppName: App名称(任务来源为2时必填)
         :type AppName: str
         :param AppVersion: App版本
         :type AppVersion: str
-        :param FileID: 上传的软件文件ID(灵犀诊断必填)
+        :param FileID: 上传的软件文件ID(任务来源为1时必填)
         :type FileID: str
-        :param AppDownloadUrl: 软件下载链接地址(灵鲲诊断必填)
+        :param AppDownloadUrl: 软件下载链接地址(任务来源为2时必填)
         :type AppDownloadUrl: str
-        :param PrivacyTextUrl: 隐私文本下载地址(灵鲲诊断必填)
+        :param PrivacyTextUrl: 隐私文本下载地址(任务来源为2时必填)
         :type PrivacyTextUrl: str
         :param ContactName: 联系人信息
         :type ContactName: str
@@ -282,6 +290,10 @@ class CreateAppScanTaskRequest(AbstractModel):
         :type IsAgreePrivacy: int
         :param PrivacyTextName: 隐私申明文件名称
         :type PrivacyTextName: str
+        :param AppSha1: 软件Sha1值(PrivacyTextMD5不为空时必填)
+        :type AppSha1: str
+        :param PrivacyTextMD5: 隐私申明文本md5(AppSha1不为空时必填)
+        :type PrivacyTextMD5: str
         """
         self.TaskType = None
         self.Source = None
@@ -300,6 +312,8 @@ class CreateAppScanTaskRequest(AbstractModel):
         self.Remark = None
         self.IsAgreePrivacy = None
         self.PrivacyTextName = None
+        self.AppSha1 = None
+        self.PrivacyTextMD5 = None
 
 
     def _deserialize(self, params):
@@ -320,6 +334,8 @@ class CreateAppScanTaskRequest(AbstractModel):
         self.Remark = params.get("Remark")
         self.IsAgreePrivacy = params.get("IsAgreePrivacy")
         self.PrivacyTextName = params.get("PrivacyTextName")
+        self.AppSha1 = params.get("AppSha1")
+        self.PrivacyTextMD5 = params.get("PrivacyTextMD5")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -362,7 +378,7 @@ class DescribeFileTicketRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Source: 任务来源, 0:默认值(私域), 1:灵犀, 2:灵鲲;
+        :param Source: 任务来源, 0:小程序诊断, 1:预留字段(暂未使用), 2:app诊断(android), 3:app漏洞扫描;
         :type Source: int
         :param Platform: 应用平台, 0:android, 1:ios, 2:小程序
         :type Platform: int
@@ -392,12 +408,12 @@ class DescribeFileTicketResponse(AbstractModel):
         r"""
         :param Result: 返回值, 0:成功, 其他值请查看“返回值”定义
         :type Result: int
-        :param UploadUrl: 上传url(灵鲲:Post方法（100:apk,101:txt）, 灵犀:put方法)
+        :param UploadUrl: 上传url(任务来源为2时:Post方法（100:apk,101:txt）, 任务来源为1时:put方法)
         :type UploadUrl: str
-        :param UploadSign: 上传url鉴权信息(灵犀上传需要, Authorization参数值)
+        :param UploadSign: 上传url鉴权信息(任务来源为1时上传需要, Authorization参数值)
 注意：此字段可能返回 null，表示取不到有效值。
         :type UploadSign: str
-        :param FildID: 上传文件ID(灵犀提交诊断任务需要)
+        :param FildID: 上传文件ID(任务来源为1时提交诊断任务需要)
 注意：此字段可能返回 null，表示取不到有效值。
         :type FildID: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -425,14 +441,26 @@ class DescribeResourceUsageInfoRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param PriceName: 资源计费项名称
+        :param PriceName: 资源计费项名称(为空时，则根据Source，TaskType和Platform进行查询)
         :type PriceName: str
+        :param TaskType: 任务类型, 0:基础版, 1:专家版
+        :type TaskType: int
+        :param Platform: 应用平台, 0:android
+        :type Platform: int
+        :param Source: 任务来源, 0:小程序诊断, 1:预留字段(暂未使用), 2:app诊断(android), 3:app漏洞扫描;
+        :type Source: int
         """
         self.PriceName = None
+        self.TaskType = None
+        self.Platform = None
+        self.Source = None
 
 
     def _deserialize(self, params):
         self.PriceName = params.get("PriceName")
+        self.TaskType = params.get("TaskType")
+        self.Platform = params.get("Platform")
+        self.Source = params.get("Source")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -476,7 +504,7 @@ class DescribeScanTaskListRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Source: 任务来源, -1:所有, 0:默认值(私域), 1:灵犀, 2:灵鲲;
+        :param Source: 任务来源, -1:所有, 0:小程序诊断, 1:预留字段(暂未使用), 2:app诊断(android), 3:app漏洞扫描;
         :type Source: int
         :param Platform: 应用平台, 0:android, 1:ios, 2:小程序
         :type Platform: int
@@ -567,7 +595,7 @@ class DescribeScanTaskReportUrlRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Source: 任务来源, 0:默认值(私域), 1:灵犀, 2:灵鲲;
+        :param Source: 任务来源, 0:小程序诊断, 1:预留字段(暂未使用), 2:app诊断(android), 3:app漏洞扫描;
         :type Source: int
         :param Platform: 应用平台, 0:android, 1:ios, 2:小程序
         :type Platform: int
@@ -575,7 +603,7 @@ class DescribeScanTaskReportUrlRequest(AbstractModel):
         :type TaskID: str
         :param TaskType: 任务类型, 0:基础版, 1:专家版, 2:本地化
         :type TaskType: int
-        :param ReportType: 报告类型, 0:诊断报告, 1:堆栈报告
+        :param ReportType: 报告类型, 0:诊断报告, 1:堆栈报告, 2:视频证据(预留), 3:报告json结果
         :type ReportType: int
         """
         self.Source = None
@@ -609,18 +637,22 @@ class DescribeScanTaskReportUrlResponse(AbstractModel):
         r"""
         :param Result: 返回值, 0:成功, 其他值请查看“返回值”定义
         :type Result: int
-        :param ReportUrl: 诊断报告/堆栈信息下载链接
+        :param ReportUrl: 诊断报告/堆栈信息/报告json结果下载链接
 注意：此字段可能返回 null，表示取不到有效值。
         :type ReportUrl: str
-        :param ReportTitle: 诊断报告/堆栈名称
+        :param ReportTitle: 诊断报告/堆栈/报告json结果的名称
 注意：此字段可能返回 null，表示取不到有效值。
         :type ReportTitle: str
+        :param ReportResult: 诊断json结果内容
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ReportResult: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.Result = None
         self.ReportUrl = None
         self.ReportTitle = None
+        self.ReportResult = None
         self.RequestId = None
 
 
@@ -628,6 +660,7 @@ class DescribeScanTaskReportUrlResponse(AbstractModel):
         self.Result = params.get("Result")
         self.ReportUrl = params.get("ReportUrl")
         self.ReportTitle = params.get("ReportTitle")
+        self.ReportResult = params.get("ReportResult")
         self.RequestId = params.get("RequestId")
 
 
@@ -638,7 +671,7 @@ class DescribeScanTaskStatusRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Source: 任务来源, 0:默认值(私域), 1:灵犀, 2:灵鲲;
+        :param Source: 任务来源, 0:小程序诊断, 1:预留字段(暂未使用), 2:app诊断(android), 3:app漏洞扫描;
         :type Source: int
         :param Platform: 应用平台, 0:android, 1:ios, 2:小程序
         :type Platform: int
